@@ -1,12 +1,14 @@
 package Class::XSAccessor::Array;
-use 5.008;
+
+use 5.006;
 use strict;
 use warnings;
 use Carp qw/croak/;
-use Class::XSAccessor;
-use Class::XSAccessor::Heavy;
 
-our $VERSION = '1.12_02';
+our $VERSION = '1.06';
+
+require Class::XSAccessor;
+require Class::XSAccessor::Heavy;
 
 sub import {
   my $own_class = shift;
@@ -20,7 +22,6 @@ sub import {
   my $read_subs      = $opts{getters} || {};
   my $set_subs       = $opts{setters} || {};
   my $acc_subs       = $opts{accessors} || {};
-  my $lvacc_subs     = $opts{lvalue_accessors} || {};
   my $pred_subs      = $opts{predicates} || {};
   my $construct_subs = $opts{constructors} || [defined($opts{constructor}) ? $opts{constructor} : ()];  
   my $true_subs      = $opts{true} || [];
@@ -30,7 +31,6 @@ sub import {
   foreach my $subtype ( ["getter", $read_subs],
                         ["setter", $set_subs],
                         ["accessor", $acc_subs],
-                        ["lvalue_accessor", $lvacc_subs],
                         ["pred_subs", $pred_subs] )
   {
     my $subs = $subtype->[1];
@@ -59,14 +59,10 @@ sub _generate_method {
   $subname = "${caller_pkg}::$subname" if $subname !~ /::/;
 
   Class::XSAccessor::Heavy::check_sub_existence($subname) if not $opts->{replace};
-  no warnings 'redefine'; # don't warn about an explicitly requested redefine
 
   if ($type eq 'getter') {
     newxs_getter($subname, $array_index);
   }
-  if ($type eq 'lvalue_accessor') {
-    newxs_lvalue_accessor($subname, $array_index);
-  }
   elsif ($type eq 'setter') {
     newxs_setter($subname, $array_index, $opts->{chained}||0);
   }
@@ -114,9 +110,6 @@ Class::XSAccessor::Array - Generate fast XS accessors without runtime compilatio
     predicates => { # test for definedness
       has_buz => 2,
     },
-    lvalue_accessors => { # see below
-      baz => 3,
-    },
     true => [ 'is_token', 'is_whitespace' ],
     false => [ 'significant' ];
   
@@ -148,7 +141,7 @@ that are implemented as B<arrays>. Using it on hash-based objects is
 bound to make your life miserable. Refer to L<Class::XSAccessor> for
 an implementation that works with hash-based objects.
 
-A simple benchmark showed a significant performance
+A simple benchmark showed more than a factor of two performance
 advantage over writing accessors in Perl.
 
 Since version 0.10, the module can also generate simple constructors
@@ -220,26 +213,6 @@ By default, the accessors are generated in the calling class. Using
 the C<class> option, you can explicitly specify where the methods
 are to be generated.
 
-=head1 LVALUES
-
-Support for lvalue accessors via the keyword C<lvalue_accessors>
-was added in version 1.08. At this point, B<THEY ARE CONSIDERED HIGHLY
-EXPERIMENTAL>. Furthermore, their performance hasn't been benchmarked
-yet.
-
-The following example demonstrates an lvalue accessor:
-
-  package Address;
-  use Class::XSAccessor
-    constructor => 'new',
-    lvalue_accessors => { zip_code => 0 };
-  
-  package main;
-  my $address = Address->new(2);
-  print $address->zip_code, "\n"; # prints 2
-  $address->zip_code = 76135; # <--- This is it!
-  print $address->zip_code, "\n"; # prints 76135
-
 =head1 CAVEATS
 
 Probably wouldn't work if your objects are I<tied>. But that's a strange thing to do anyway.
@@ -271,14 +244,13 @@ L<AutoXS>
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
-chocolateboy E<lt>chocolate@cpan.orgE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008, 2009, 2010, 2011 by Steffen Mueller
+Copyright (C) 2008-2009 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
+
